@@ -10,7 +10,6 @@ import threading
 import time
 from datetime import datetime
 
-import random
 import configparser
 import yaml
 
@@ -164,6 +163,8 @@ validators = [
     Validator('general.parse_embedded_audio_track', must_exist=True, default=False, is_type_of=bool),
     Validator('general.skip_hashing', must_exist=True, default=False, is_type_of=bool),
     Validator('general.language_equals', must_exist=True, default=[], is_type_of=list),
+    Validator('general.concurrent_jobs', must_exist=True, default=4 if os.cpu_count() >= 4 else os.cpu_count(),
+              is_type_of=int),
 
     # log section
     Validator('log.include_filter', must_exist=True, default='', is_type_of=str, cast=str),
@@ -284,20 +285,12 @@ validators = [
     Validator('proxy.password', must_exist=True, default='', is_type_of=str, cast=str),
     Validator('proxy.exclude', must_exist=True, default=["localhost", "127.0.0.1"], is_type_of=list),
 
-    # opensubtitles.org section
-    Validator('opensubtitles.username', must_exist=True, default='', is_type_of=str, cast=str),
-    Validator('opensubtitles.password', must_exist=True, default='', is_type_of=str, cast=str),
-    Validator('opensubtitles.use_tag_search', must_exist=True, default=False, is_type_of=bool),
-    Validator('opensubtitles.vip', must_exist=True, default=False, is_type_of=bool),
-    Validator('opensubtitles.ssl', must_exist=True, default=False, is_type_of=bool),
-    Validator('opensubtitles.timeout', must_exist=True, default=15, is_type_of=int, gte=1),
-    Validator('opensubtitles.skip_wrong_fps', must_exist=True, default=False, is_type_of=bool),
-
     # opensubtitles.com section
     Validator('opensubtitlescom.username', must_exist=True, default='', is_type_of=str, cast=str),
     Validator('opensubtitlescom.password', must_exist=True, default='', is_type_of=str, cast=str),
     Validator('opensubtitlescom.use_hash', must_exist=True, default=True, is_type_of=bool),
     Validator('opensubtitlescom.include_ai_translated', must_exist=True, default=False, is_type_of=bool),
+    Validator('opensubtitlescom.include_machine_translated', must_exist=True, default=False, is_type_of=bool),
 
     # napiprojekt section
     Validator('napiprojekt.only_authors', must_exist=True, default=False, is_type_of=bool),
@@ -504,6 +497,9 @@ elif not os.path.exists(config_yaml_file):
         os.makedirs(os.path.dirname(config_yaml_file))
     open(config_yaml_file, mode='w').close()
 
+if os.path.exists(config_yaml_file):
+    os.environ['BAZARR_CONFIGURED'] = '1'
+
 settings = Dynaconf(
     settings_file=config_yaml_file,
     core_loaders=['YAML'],
@@ -786,15 +782,6 @@ def save_settings(settings_items):
                 reset_providers = True
                 region.delete('legendasdivx_cookies2')
 
-        if key == 'settings-opensubtitles-username':
-            if key != settings.opensubtitles.username:
-                reset_providers = True
-                region.delete('os_token')
-        elif key == 'settings-opensubtitles-password':
-            if key != settings.opensubtitles.password:
-                reset_providers = True
-                region.delete('os_token')
-
         if key == 'settings-opensubtitlescom-username':
             if key != settings.opensubtitlescom.username:
                 reset_providers = True
@@ -887,6 +874,12 @@ def save_settings(settings_items):
     else:
         write_config()
 
+        # Set the configured state based on config.yaml file existence
+        from .database import database, update, System
+        database.execute(
+            update(System)
+            .values(configured=1))
+
         # Reconfigure Bazarr to reflect changes
         if configure_debug:
             from .logger import configure_logging
