@@ -10,6 +10,7 @@ from subzero.language import Language
 from app.config import settings
 from languages.custom_lang import CustomLanguage
 from languages.get_languages import alpha3_from_alpha2
+from subtitles.indexer.utils import get_external_subtitles_path
 
 
 def subtitles_apply_mods(language, subtitle_path, mods, video_path):
@@ -32,9 +33,22 @@ def subtitles_apply_mods(language, subtitle_path, mods, video_path):
     content = sub.get_modified_content(format=sub.format)
     if content:
         if hasattr(sub, 'mods') and isinstance(sub.mods, list) and 'remove_HI' in sub.mods:
-            modded_subtitles_path = get_subtitle_path(video_path, None if single else sub.language,
-                                                      forced_tag=sub.language.forced, hi_tag=False, tags=[],
-                                                      extension=f".{sub.format}")
+            # get the modded subtitles path if the subtitles are alongside the video
+            modded_subtitles_path_if_alongside_video = get_subtitle_path(
+                video_path,
+                language=None if single else sub.language,
+                forced_tag=sub.language.forced,
+                hi_tag=False,
+                tags=[],
+                extension=f".{sub.format}"
+            )
+
+            # get the real modded subtitles path taking into account if the user set up Bazarr to store external
+            # subtitles in a custom folder or relative folder
+            modded_subtitles_path = get_external_subtitles_path(
+                file=video_path,
+                subtitle=os.path.basename(modded_subtitles_path_if_alongside_video)
+            )
         else:
             modded_subtitles_path = subtitle_path
 
