@@ -125,6 +125,9 @@ def wanted_search_missing_subtitles_movies(job_id=None):
         providers = get_providers()
         if providers:
             wanted_download_subtitles_movie(movie.radarrId, job_id=job_id)
+
+            # make sure to override the progress value updated by the subtitles synchronization
+            jobs_queue.update_job_progress(job_id=job_id, progress_value=i, progress_max=count_movies)
         else:
             logging.info("BAZARR All providers are throttled")
             break
