@@ -285,14 +285,12 @@ class WhisperAISubtitle(Subtitle):
         return f"{self.video.original_name}_{self.task}_{str(self.language)}"
 
     def get_matches(self, video):
-        matches = set()
-
         if isinstance(video, Episode):
-            matches.update(["series", "season", "episode"])
+            self.matches.update(["series", "season", "episode"])
         elif isinstance(video, Movie):
-            matches.update(["title"])
+            self.matches.update(["title"])
 
-        return matches
+        return self.matches
 
 
 class WhisperAIProvider(Provider):
@@ -352,7 +350,7 @@ class WhisperAIProvider(Provider):
                 # 0 = Pick first stream in case there are multiple language streams of the same language,
                 # otherwise ffmpeg will try to combine multiple streams, but our output format doesn't support that.
                 # The first stream is probably the correct one, as later streams are usually commentaries
-                lang_map = f"0:m:language:{audio_stream_language}"
+                lang_map = f"0:a:m:language:{audio_stream_language}"
                 out = inp.output("-", format="s16le", acodec="pcm_s16le", ac=1, ar=16000, af="aresample=async=1",
                                  map=lang_map)
             else:
